@@ -21,8 +21,6 @@ from pyhocon import ConfigFactory, ConfigTree
 from databuilder.publisher.base_publisher import Publisher
 from databuilder.publisher.neo4j_preprocessor import NoopRelationPreprocessor
 
-logging.basicConfig(level=logging.DEBUG)
-
 # Setting field_size_limit to solve the error below
 # _csv.Error: field larger than field limit (131072)
 # https://stackoverflow.com/a/54517228/5972935
@@ -255,7 +253,7 @@ class Neo4jCsvPublisherApoc(Publisher):
         CALL apoc.periodic.iterate(
             'UNWIND $rows AS row RETURN row', 
             'CALL apoc.merge.node([row.label], {key:row.key}, row, row) YIELD node RETURN COUNT(*);', 
-            {batchSize: $batch_size, iterateList: True, parallel: False, params: { rows: $batch, tag: $publish_tag }}
+            {batchSize: $batch_size, iterateList: True, parallel: True, params: { rows: $batch, tag: $publish_tag }}
         );
         :param node_file:
         :return:
@@ -311,13 +309,13 @@ class Neo4jCsvPublisherApoc(Publisher):
             return """            
                     CALL apoc.periodic.iterate('UNWIND $rows AS row RETURN row', '
                         CALL apoc.merge.node([row.LABEL], {key:row.KEY}, row, {published_tag:$tag,publisher_last_updated_epoch_ms:timestamp()}) YIELD node RETURN COUNT(*);
-                    ', {batchSize: $batch_size, iterateList: True, parallel: False, params: { rows: $batch, tag: $publish_tag }})
+                    ', {batchSize: $batch_size, iterateList: True, parallel: True, params: { rows: $batch, tag: $publish_tag }})
                 """
 
         return """            
             CALL apoc.periodic.iterate('UNWIND $rows AS row RETURN row', '
                 CALL apoc.merge.node([row.LABEL], {key:row.KEY}, row, row) YIELD node RETURN COUNT(*);
-            ', {batchSize: $batch_size, iterateList: True, parallel: False, params: { rows: $batch }})
+            ', {batchSize: $batch_size, iterateList: True, parallel: True, params: { rows: $batch }})
         """
 
     def _publish_relation(self, relation_file: str) -> None:
@@ -331,7 +329,7 @@ class Neo4jCsvPublisherApoc(Publisher):
              CALL apoc.merge.relationship(n1, row.type, {}, {{PROPS}}, n2, {{PROPS}}) YIELD rel AS r1
              CALL apoc.merge.relationship(n2, row.reverse_type, {}, {{PROPS}}, n1, {{PROPS}}) YIELD rel AS r2
              RETURN n1.key, n2.key', 
-            {batchSize: $batch_size, parallel: False, params: { rows: $batch, tag: $publish_tag }}
+            {batchSize: $batch_size, parallel: True, params: { rows: $batch, tag: $publish_tag }}
         )
         :param relation_file:
         :return:
@@ -402,7 +400,7 @@ class Neo4jCsvPublisherApoc(Publisher):
                 CALL apoc.merge.relationship(n1, row.TYPE, {}, {published_tag:$tag,publisher_last_updated_epoch_ms:timestamp()}, n2, {published_tag:$tag,publisher_last_updated_epoch_ms:timestamp()}) YIELD rel AS r1
                 CALL apoc.merge.relationship(n2, row.REVERSE_TYPE, {}, {published_tag:$tag,publisher_last_updated_epoch_ms:timestamp()}, n1, {published_tag:$tag,publisher_last_updated_epoch_ms:timestamp()}) YIELD rel AS r2
                 RETURN n1.key, n2.key
-            ', {batchSize: $batch_size, parallel: False, params: { rows: $batch, tag: $publish_tag }})
+            ', {batchSize: $batch_size, parallel: True, params: { rows: $batch, tag: $publish_tag }})
         """
 
     def _execute_statement(self,
@@ -421,14 +419,8 @@ class Neo4jCsvPublisherApoc(Publisher):
             try:
                 LOGGER.debug('Executing statement: %s with params %s', stmt, params)
 
-                LOGGER.info(stmt)
-                LOGGER.info(params)
-                
                 result = session.run(str(stmt).encode('utf-8', 'ignore'), parameters=params)
 
-                LOGGER.info("result")
-                LOGGER.info(result)
-
                 if expect_result and not result.single():
                     raise RuntimeError(f'Failed to executed statement: {stmt}')
 
